
# q-expansion of newform 6762.2.a.r, downloaded from the LMFDB on 10 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K.gens()[0]**i for i in range(len(poly_data))]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6762
weight = 2
poly_data = [0, 1]

# The basis for the coefficient ring is just the power basis
# in the root of the defining polynomial above.
hecke_ring_character_values = None
aps_data = [[-1], [1], [2], [0], [0], [-4], [0], [-6], [-1], [-6], [10], [-6], [2], [12], [-10], [-10], [12], [14], [-12], [-12], [-14], [0], [-2], [12], [-12], [0], [4], [8], [-10], [-14], [-12], [-4], [-18], [0], [18], [12], [2], [-12], [-14], [24], [-4], [-2], [0], [-10], [6], [-20], [-28], [-18], [-14], [6], [22], [20], [-24], [-18], [6], [16], [24], [2], [-10], [-2], [18], [18], [-16], [-10], [8], [-2], [-20], [14], [4], [16], [26], [0], [20], [-14], [24], [-16], [-18], [12], [22], [22], [14], [-26], [-24], [-4], [22], [36], [14], [26], [0], [-16], [-6], [-36], [-16], [-20], [-44], [24], [16], [-28], [-38], [-10], [28], [18], [22], [46], [4], [10], [-16], [-42], [16], [26], [34], [14], [22], [6], [16], [-2], [46], [-38], [-46], [-36], [-26], [14], [-30], [-12], [-8], [2], [10], [18], [-36], [-6], [-20], [-8], [-8], [-2], [30], [-16], [6], [-2], [-18], [-2], [-28], [6], [36], [0], [12], [-48], [12], [-38], [-56], [-4], [10], [32], [-12], [10], [-32], [-8], [40], [18], [-56], [-6], [20], [-30], [-32], [22], [30], [32], [20], [-28], [-22], [20], [24], [8], [40], [14], [-10], [60], [-28], [18], [40], [2], [-12], [6], [-54], [58], [-40], [-10], [62], [-58], [-10], [-18], [-26], [36], [0], [4], [-12], [4], [46], [-34], [8], [66], [46], [26], [-68], [-40], [-6], [4], [-8], [-20], [26], [40], [58], [0], [-8], [18], [-18], [-8], [-40], [-50], [32], [-6], [-30], [8], [66], [8], [-28], [-30], [20], [36], [-28], [60], [-14], [30], [56], [-42], [-14], [68], [-8], [-10], [-36], [-10], [-12], [-28], [42], [54], [-42], [62], [-62], [38], [36], [-72], [-18], [12], [40], [56], [32], [-12], [-2], [-66], [52], [-18], [64], [-28], [12], [-26], [-46], [14], [18], [52], [52], [34], [24], [32], [28], [16], [26], [26], [-60], [-42], [34], [18], [30], [-8], [-32], [6], [-16], [60], [26], [-6], [78], [-6], [10], [-22], [-78], [6], [46], [2], [16], [84], [24], [60], [-36], [6], [-72], [-36], [-4], [-38], [44], [-66], [-48], [-10], [-30], [-26], [-66], [-76], [-48], [-28], [0], [-28], [-4], [50], [-14], [22], [24], [64], [18], [16], [4], [8], [24], [58], [38], [26], [26], [-36], [-68], [0], [66], [-36], [-26], [56], [-10], [-66], [4], [-64], [-90], [12], [-28], [-68], [40], [26], [-52], [74], [-26], [56], [-6], [-30], [0], [-78], [-74], [-16], [22], [-30], [48], [28], [52], [22], [-76], [24], [2], [-60], [32], [0], [74], [-4], [-2], [-80], [-88], [-32], [52], [50], [-66], [66], [20], [-78], [-74], [94], [68], [12], [4], [-96], [-98], [36], [-4], [40], [-64], [6], [24], [-52], [-16], [66], [8], [-42], [32], [52], [28], [14], [-30], [22], [-62], [8], [54], [-30], [-36], [-88], [-26], [-64], [-64], [-50], [-68], [-24], [-94], [74], [48], [-52], [-10], [24], [-80], [42], [48], [78]]
